﻿using System;
using System.Data;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using System.Text;
using System.Web.UI;

/// <summary>
/// Summary description for AjaxRadGrid
/// </summary>
namespace MyNamespace
{
    public class AjaxRadGrid : CompositeControl
    {
        private RadAjaxManager _radAjax;
        private RadGrid _radGrid;
        private RadToolBar _radToolBar;

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            _radAjax = RadAjaxManager.GetCurrent(Page);
            if (_radAjax == null)
            {
                _radAjax = new RadAjaxManager();
                _radAjax.ID = "RadAjaxManager1";
                _radAjax.AjaxRequest += new RadAjaxControl.AjaxRequestDelegate(_radAjax_AjaxRequest);
                Controls.Add(_radAjax);
            }
        }

        void _radAjax_AjaxRequest(object sender, AjaxRequestEventArgs e)
        {
            string command = (e.Argument);

            switch (command)
            {
                case "refresh":
                    _radGrid.Rebind();
                    break;
                case "test":
                    // Changing the grid structure dynamically
                    // Only Column #1 & #3
                    _radGrid.Columns.Clear();

                    GridBoundColumn col1 = new GridBoundColumn();
                    col1.DataField = "Col1";
                    col1.HeaderText = "Column #1";
                    _radGrid.Columns.Add(col1);

                    GridBoundColumn col3 = new GridBoundColumn();
                    col3.DataField = "Col3";
                    col3.HeaderText = "Column #3";
                    _radGrid.Columns.Add(col3);

                    _radGrid.Rebind();
                    break;
                default:
                    break;
            }
        }

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            _radToolBar = new RadToolBar();
            RadToolBarButton btnTest = new RadToolBarButton("Changing the grid structure dynamically");
            btnTest.Value = "test";
            _radToolBar.Items.Add(btnTest);
            RadToolBarButton btnRefresh = new RadToolBarButton("Refresh");
            btnRefresh.Value = "refresh";
            _radToolBar.Items.Add(btnRefresh);

            Controls.Add(_radToolBar);

            _radGrid = new RadGrid();
            _radGrid.ID = "RadGrid1";
            _radGrid.NeedDataSource += radGrid_NeedDataSource;
            _radGrid.AllowSorting = true;
            _radGrid.AllowPaging = true;
            _radGrid.AllowFilteringByColumn = true;

            _radGrid.MasterTableView.EnableColumnsViewState = true;

            _radGrid.AutoGenerateColumns = false;
            _radGrid.Columns.Clear();

            GridBoundColumn col1 = new GridBoundColumn();
            col1.DataField = "Col1";
            col1.HeaderText = "Column #1";
            _radGrid.Columns.Add(col1);

            GridBoundColumn col2 = new GridBoundColumn();
            col2.DataField = "Col2";
            col2.HeaderText = "Random Number";
            _radGrid.Columns.Add(col2);

            GridBoundColumn col3 = new GridBoundColumn();
            col3.DataField = "Col3";
            col3.HeaderText = "Column #3";
            _radGrid.Columns.Add(col3);

            Controls.Add(_radGrid);
        }

        void radGrid_NeedDataSource(object source, GridNeedDataSourceEventArgs e)
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Col1");
            dt.Columns.Add("Col2");
            dt.Columns.Add("Col3");
            Random random = new Random();

            for (int i = 0; i < 100; i++)
            {
                dt.Rows.Add(new object[] { "col1" + i, random.Next(1, 100), DateTime.Now.ToLongTimeString() });
            }
            ((RadGrid)source).DataSource = dt;
        }

        protected override void OnPreRender(EventArgs e)
        {
            base.OnPreRender(e);
            _radAjax.AjaxSettings.AddAjaxSetting(_radGrid, _radGrid);

            StringBuilder js = new StringBuilder();
            js.AppendLine("function pageLoad(sender, args) {");
            js.AppendFormat("    Init('{0}', '{1}', '{2}');", _radAjax.ClientID, _radGrid.ClientID, _radToolBar.ClientID);
            js.AppendLine("}");
            ScriptManager.RegisterStartupScript(this.Page, this.GetType(), "Init", js.ToString(), true);
        }
    }

}

